#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 kmonad
version:              0.4.5
visibility:           public
id:                   kmonad-0.4.5-CyWUNOkq94p4ARS5HAUdBh
key:                  kmonad-0.4.5-CyWUNOkq94p4ARS5HAUdBh
license:              MIT
maintainer:           janssen.dhj@gmail.com
author:               David Janssen
synopsis:             Advanced keyboard remapping utility
description:
    KMonad is a cross-platform command-line utility that runs as a daemon. It
    captures keyboard input (exactly how depends on the OS) and remaps it. The
    mapping is highly configurable, and provides options like (transparent) layer
    overlays, tap-mod buttons, multi-tap buttons, leader-key style buttons, and
    keyboard macros. Functionality heavily inspired by the QMK-firmware.

category:             Application
abi:                  8be62955e42066496827f8ba421f3779
exposed:              True
exposed-modules:
    KMonad.App KMonad.App.Main KMonad.App.Types KMonad.Args
    KMonad.Args.Cmd KMonad.Args.Joiner KMonad.Args.Parser
    KMonad.Args.TH KMonad.Args.Types KMonad.Gesture KMonad.Keyboard
    KMonad.Keyboard.ComposeSeq KMonad.Keyboard.IO
    KMonad.Keyboard.IO.Linux.DeviceSource
    KMonad.Keyboard.IO.Linux.Types KMonad.Keyboard.IO.Linux.UinputSink
    KMonad.Keyboard.IO.Mac.Types KMonad.Keyboard.IO.Windows.Types
    KMonad.Keyboard.Keycode KMonad.Keyboard.Ops KMonad.Keyboard.Types
    KMonad.Model KMonad.Model.Action KMonad.Model.BEnv
    KMonad.Model.Button KMonad.Model.Dispatch KMonad.Model.EventSrc
    KMonad.Model.Hooks KMonad.Model.Keymap KMonad.Model.Sluice
    KMonad.Parsing KMonad.Prelude KMonad.Prelude.Definitions
    KMonad.Prelude.Imports KMonad.Util KMonad.Util.LayerStack
    KMonad.Util.MultiMap Paths_kmonad

import-dirs:          /usr/lib/ghc-9.6.6/site-local/kmonad-0.4.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/kmonad-0.4.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/kmonad-0.4.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/kmonad
hs-libraries:         HSkmonad-0.4.5-CyWUNOkq94p4ARS5HAUdBh
depends:
    base-4.18.2.1 cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK
    hashable-1.4.7.0-A1kp0rRlB2mBNtk1x2NHGT
    hinotify-0.4.2-8u6cTLekyDILEaA9PBnOCY
    lens-5.3.5-ApAD4D8hy7K2t3Q7L3bBvG
    megaparsec-9.7.1-lfMyUtNLhmEXQ4ic9tvxz mtl-2.3.1
    optparse-applicative-0.18.1.0-8Us6opzobWeE8qMBykWiRI
    resourcet-1.3.0-HYdPrsWCzneJIcOsQDIVse
    rio-0.1.25.0-A1xmpAj0yy03sIARUcpHUN template-haskell-2.20.0.0
    time-1.12.2 transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-JOKqT5DcdDFKqQgMQFlxcn

haddock-interfaces:   /usr/share/doc/kmonad/html/kmonad.haddock
haddock-html:         /usr/share/doc/kmonad/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

